#!/usr/bin/env python

import inkex
# simplestyle module provides functions for style parsing.
from simplestyle import *

""" Example Inkscape effect extension.
Creates a layer with a circular path."""
class CirclesEffect(inkex.Effect):
	""" Constructor.
	Defines "--what" option of a script."""
	def __init__(self):
		# Call base class construtor.
		inkex.Effect.__init__(self)

		# Define string option "--what" with "-w" shortcut and default value "World".		
		self.OptionParser.add_option('-s', '--startradius', action = 'store',
		type = 'int', dest = 'start_radius', default = 40,
		help = 'Start Radius?')

		self.OptionParser.add_option('-w', '--ringwidth', action = 'store',
		type = 'int', dest = 'ring_width', default = 40,
		help = 'Ring Width?')
		
		self.OptionParser.add_option('-m', '--ringwidthmultiplier', action = 'store',
		type = 'float', dest = 'ring_width_multiplier', default = 1.0,
		help = 'Ring Width Multiplier?')
		
		self.OptionParser.add_option('-n', '--minringwidth', action = 'store',
		type = 'int', dest = 'min_ring_width', default = 5,
		help = 'Max Ring Width?')
		
		self.OptionParser.add_option('-x', '--maxringwidth', action = 'store',
		type = 'int', dest = 'max_ring_width', default = 100,
		help = 'Min Ring Width?')

	""" Effect behaviour. Overrides base class' method."""
	def effect(self):
		# Get access to main SVG document element and get its dimensions.
		svg = self.document.getElementsByTagName('svg')[0]
		width = inkex.unittouu(svg.getAttribute('width'))
		height = inkex.unittouu(svg.getAttribute('height'))

		# Create a new layer.
		layer = self.document.createElement('g')
		layer.setAttribute('inkscape:label', 'Circles Layer')
		layer.setAttribute('inkscape:groupmode', 'layer')

		# Get all the options
		start_radius = self.options.start_radius
		ring_width = self.options.ring_width
		ring_width_multiplier = self.options.ring_width_multiplier
		min_ring_width = self.options.min_ring_width
		max_ring_width = self.options.max_ring_width

		radius = start_radius
		# set the max_radius to the larger of the two page dimensions
		# (to fill page + spillover)
		# using min would fit entirely on the page
		max_radius = max(width, height) * 0.5
		
		while (radius < max_radius):
			# Create path element
			path = self.document.createElement('path')
			path.setAttribute("sodipodi:type", "arc")
			path.setAttribute("sodipodi:cx", str(width/2))
			path.setAttribute("sodipodi:cy", str(height/2))
			path.setAttribute("sodipodi:rx", str(radius))
			path.setAttribute("sodipodi:ry", str(radius))
			# path.setAttribute("style", "fill:none;stroke:#000000;stroke-width:1px;stroke-opacity:1")
			style = {
				'fill' : 'none',
				'stroke': '#000000',
				'stroke-width' : '0.5px',
				'stroke-opacity' : '1.0'
			}
			path.setAttribute('style', formatStyle(style))
	
			# Connect elements together.
			layer.appendChild(path)
			# add the ring_width, limiting to min / max
			# radius += min(max_ring_width, max(min_ring_width, ring_width))
			radius += ring_width
			# scale the ring_width by the multiplier
			# (allowing shrinking / growing)
			ring_width *= ring_width_multiplier

		svg.appendChild(layer)

# Create effect instance and apply it.
effect = CirclesEffect()
effect.affect()
